@@ -28,7 +28,7 @@ class EPUBElementTree:
         'ibooks': 'http://vocabulary.itunes.apple.com/rdf/ibooks/vocabulary-extensions-1.0/',
         'ncx': 'http://www.daisy.org/z3986/2005/ncx/',
         'xhtml': 'http://www.w3.org/1999/xhtml',
-        'epub': 'http://www.idpf.org/2007/ops'
+        'epub': 'http://www.idpf.org/2007/ops',
     }
 
     def __init__(self, tree):
@@ -36,7 +36,8 @@ class EPUBElementTree:
 
     @classmethod
     def fromstring(cls, string):
-        return cls(ElementTree.fromstring(string))
+        tree = ElementTree.fromstring(string)  # NoQA: S314  # using known data in tests
+        return cls(tree)
 
     def find(self, match):
         ret = self.tree.find(match, namespaces=self.namespaces)
@@ -59,7 +60,7 @@ class EPUBElementTree:
 
 @pytest.mark.sphinx('epub', testroot='basic')
 def test_build_epub(app):
-    app.build()
+    app.builder.build_all()
     assert (app.outdir / 'mimetype').read_text(encoding='utf8') == 'application/epub+zip'
     assert (app.outdir / 'META-INF' / 'container.xml').exists()
 
@@ -276,7 +277,7 @@ def test_escaped_toc(app):
 @pytest.mark.sphinx('epub', testroot='basic')
 def test_epub_writing_mode(app):
     # horizontal (default)
-    app.build()
+    app.builder.build_all()
 
     # horizontal / page-progression-direction
     opf = EPUBElementTree.fromstring((app.outdir / 'content.opf').read_text(encoding='utf8'))
@@ -366,7 +367,7 @@ def test_html_download_role(app, status, warning):
 
 @pytest.mark.sphinx('epub', testroot='toctree-duplicated')
 def test_duplicated_toctree_entry(app, status, warning):
-    app.build()
+    app.builder.build_all()
     assert 'WARNING: duplicated ToC entry found: foo.xhtml' in warning.getvalue()
 
 
